@@ -143,12 +143,31 @@ typedef struct diskperf_t {
 
 static int timerNeedsUpdate = 0;
 
+static void UpdateProgressBars(struct diskperf_t *p_poPlugin, uint64_t rw, uint64_t r, uint64_t w) {
+ /* Update combined or separate progress bars with actual data */
+    struct monitor_t *poMonitor = &(p_poPlugin->oMonitor);
+    struct param_t *poConf = &(p_poPlugin->oConf.oParam);
+    struct perfbar_t *poPerf = poMonitor->aoPerfBar;
+
+    if (poConf->fRW_DataCombined)
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR
+				       (*(poPerf[RW_DATA].pwBar)),
+				       rw);
+    else {
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR
+				       (*(poPerf[R_DATA].pwBar)),
+				       r);
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR
+				       (*(poPerf[W_DATA].pwBar)),
+				       w);
+    }
+}
+
+
 static int DisplayPerf (struct diskperf_t *p_poPlugin)
  /* Get the last disk perfomance data, compute the statistics and update
     the panel-docked monitor bars */
 {
-    static GtkTooltips *s_poToolTips = 0;
-
     struct devperf_t oPerf;
     struct param_t *poConf = &(p_poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(p_poPlugin->oMonitor);
@@ -163,9 +182,6 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
     char            acToolTips[256];
     int             status, i;
 
-    if (!s_poToolTips)
-	s_poToolTips = gtk_tooltips_new ();
-
     rbytes = wbytes = iRBusy_ns = iWBusy_ns = -1;
     memset (&oPerf, 0, sizeof (oPerf));
     oPerf.qlen = -1;
@@ -177,10 +193,11 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
     status = DevGetPerfData (&(poConf->st_rdev), &oPerf);
 #endif
     if (status == -1) {
-    snprintf (acToolTips, sizeof(acToolTips), "%s: Device statistics unavailable.",
+    snprintf (acToolTips, sizeof(acToolTips), _("%s: Device statistics unavailable."),
               poConf->acTitle);
-    gtk_tooltips_set_tip (s_poToolTips, GTK_WIDGET (poMonitor->wEventBox),
-			  acToolTips, 0);
+    UpdateProgressBars(p_poPlugin, 0, 0, 0);
+    gtk_widget_set_tooltip_text(GTK_WIDGET(poMonitor->wEventBox), acToolTips);
+
 	return (-1);
     }
     if (poMonitor->oPrevPerf.timestamp_ns) {
@@ -216,9 +233,9 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
 	}
     }
 
-    snprintf (acToolTips, sizeof(acToolTips), "%s\n"
+    snprintf (acToolTips, sizeof(acToolTips), _("%s\n"
 	     "----------------\n"
-	     "I/O    (MB/s)\n"
+	     "I/O    (MiB/s)\n"
 	     "  Read :%3.2f\n"
 	     "  Write :%3.2f\n"
 	     "  Total :%3.2f\n"
@@ -227,7 +244,7 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
 	     "  Read : %3d\n"
 	     "  Write : %3d\n"
 #endif
-	     "  Total : %3d",
+         "  Total : %3d"),
 	     poConf->acTitle,
 	     arPerf[R_DATA],
 	     arPerf[W_DATA],
@@ -240,8 +257,7 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
 	     (int) round(arBusy[W_DATA]) : -1,
 #endif
 	     (oPerf.qlen >= 0) ? (int) round(arBusy[RW_DATA]) : -1);
-    gtk_tooltips_set_tip (s_poToolTips, GTK_WIDGET (poMonitor->wEventBox),
-			  acToolTips, 0);
+    gtk_widget_set_tooltip_text(GTK_WIDGET(poMonitor->wEventBox), acToolTips);
 
     switch (poConf->eStatistics) {
 	case BUSY_TIME:
@@ -263,18 +279,7 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
 	else if (*pr < 0)
 	    *pr = 0;
     }
-    if (poConf->fRW_DataCombined)
-	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR
-				       (*(poPerf[RW_DATA].pwBar)),
-				       prData[RW_DATA]);
-    else {
-	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR
-				       (*(poPerf[R_DATA].pwBar)),
-				       prData[R_DATA]);
-	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR
-				       (*(poPerf[W_DATA].pwBar)),
-				       prData[W_DATA]);
-    }
+    UpdateProgressBars(p_poPlugin, prData[RW_DATA], prData[R_DATA], prData[W_DATA]);
 
     return (0);
 }				/* DisplayPerf() */
@@ -296,6 +301,14 @@ static gboolean SetTimer (void *p_pvPlugin)
         timerNeedsUpdate = 0;
     }
 
+    /* reduce the default tooltip timeout to be smaller than the update interval otherwise
+     * we won't see tooltips on GTK 2.16 or newer */
+    GtkSettings *settings;
+    settings = gtk_settings_get_default();
+    if (g_object_class_find_property(G_OBJECT_GET_CLASS(settings), "gtk-tooltip-timeout"))
+        g_object_set(settings, "gtk-tooltip-timeout",
+                     poConf->iPeriod_ms - 10, NULL);
+
     if (!poPlugin->iTimerId)
         poPlugin->iTimerId = g_timeout_add (poConf->iPeriod_ms,
 					    (GSourceFunc) SetTimer, poPlugin);
@@ -538,6 +551,14 @@ static void diskperf_read_config (XfcePanelPlugin *plugin,
     else
         gtk_widget_hide (GTK_WIDGET (poMonitor->wTitle));
 
+#ifdef HAS_PANEL_49
+    /* unset small if we are in deskbar mode and we want the title */
+    if (poConf->fTitleDisplayed && xfce_panel_plugin_get_mode(poPlugin->plugin) == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
+      xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), FALSE);
+    else
+      xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), TRUE);
+#endif
+
     if ((value = xfce_rc_read_entry (rc, (CONF_LABEL_TEXT), NULL))) {
         memset (poConf->acTitle, 0, sizeof (poConf->acTitle));
         strncpy (poConf->acTitle, value, sizeof (poConf->acTitle) - 1);
@@ -672,8 +693,17 @@ static void ToggleTitle (Widget_t p_w, void *p_pvPlugin)
 	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (p_w));
     if (poConf->fTitleDisplayed)
 	gtk_widget_show (GTK_WIDGET (poMonitor->wTitle));
+
     else
 	gtk_widget_hide (GTK_WIDGET (poMonitor->wTitle));
+
+#ifdef HAS_PANEL_49
+    /* unset small if we are in deskbar mode and we want the title */
+    if (poConf->fTitleDisplayed && xfce_panel_plugin_get_mode(poPlugin->plugin) == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
+      xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), FALSE);
+    else
+      xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), TRUE);
+#endif
 }				/* ToggleTitle() */
 
 	/**************************************************************/
@@ -1114,6 +1144,12 @@ static void diskperf_set_mode (XfcePanelPlugin *plugin,
     gtk_label_set_angle (GTK_LABEL (poMonitor->wTitle),
                          (p_iMode != XFCE_PANEL_PLUGIN_MODE_VERTICAL) ?
                          0 : 270);
+    /* unset small if we are in deskbar mode and we want the title */
+    if (poPlugin->oConf.oParam.fTitleDisplayed && p_iMode == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
+      xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (plugin), FALSE);
+    else
+      xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (plugin), TRUE);
+
     diskperf_set_size (plugin, xfce_panel_plugin_get_size (plugin), poPlugin);
 }				/* diskperf_set_orientation() */
 #else
@@ -1158,6 +1194,7 @@ static void diskperf_construct (XfcePanelPlugin *plugin)
 #ifdef HAS_PANEL_49
     g_signal_connect (plugin, "mode-changed",
                       G_CALLBACK (diskperf_set_mode), diskperf);
+    xfce_panel_plugin_set_small (plugin, TRUE);
 #else
     g_signal_connect (plugin, "orientation-changed",
                       G_CALLBACK (diskperf_set_orientation), diskperf);
